http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/VersionedCacheableObjectPartList.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/VersionedCacheableObjectPartList.cpp 
b/src/cppcache/src/VersionedCacheableObjectPartList.cpp
index c291d29..8d5e4d6 100644
--- a/src/cppcache/src/VersionedCacheableObjectPartList.cpp
+++ b/src/cppcache/src/VersionedCacheableObjectPartList.cpp
@@ -22,7 +22,9 @@
 #include "CacheableToken.hpp"
 #include "DiskStoreId.hpp"
 #include "DiskVersionTag.hpp"
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 
 const uint8_t VersionedCacheableObjectPartList::FLAG_NULL_TAG = 0;
 const uint8_t VersionedCacheableObjectPartList::FLAG_FULL_TAG = 1;
@@ -81,7 +83,8 @@ void VersionedCacheableObjectPartList::readObjectPart(int32_t 
index,
 
     /* adongre
      * CID 29377: Resource leak (RESOURCE_LEAK)Calling allocation function
-     * "gemfire::DataInput::readBytes(unsigned char **, int *)" on "bytes".
+     * "apache::geode::client::DataInput::readBytes(unsigned char **, int *)" 
on
+     * "bytes".
      */
     GF_SAFE_DELETE_ARRAY(bytes);
 
@@ -323,4 +326,6 @@ int8_t VersionedCacheableObjectPartList::DSFID() const {
 }
 
 uint32_t VersionedCacheableObjectPartList::objectSize() const { return 0; }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/VersionedCacheableObjectPartList.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/VersionedCacheableObjectPartList.hpp 
b/src/cppcache/src/VersionedCacheableObjectPartList.hpp
index 6e4a264..3de15c3 100644
--- a/src/cppcache/src/VersionedCacheableObjectPartList.hpp
+++ b/src/cppcache/src/VersionedCacheableObjectPartList.hpp
@@ -37,7 +37,9 @@
 /** @file
  */
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ThinClientRegion;
 
 /**
@@ -277,6 +279,8 @@ class VersionedCacheableObjectPartList : public 
CacheableObjectPartList {
 
   virtual uint32_t objectSize() const;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_VERSIONEDCACHEABLEOBJECTPARTLIST_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/dllmain.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/dllmain.cpp b/src/cppcache/src/dllmain.cpp
index e028610..1dfdfba 100644
--- a/src/cppcache/src/dllmain.cpp
+++ b/src/cppcache/src/dllmain.cpp
@@ -99,7 +99,9 @@ void DllMainGetPath(char *result, int maxLen) {
 
 #ifdef _WIN32
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 void CPPCACHE_EXPORT setNewAndDelete(pNew pn, pDelete pd) {
   Utils::s_pNew = pn;
   Utils::s_pDelete = pd;
@@ -138,7 +140,8 @@ operators.");
   }
 }
 */
-
-}  // namespace gemfire
+}
+}
+}
 
 #endif  // _WIN32

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/gfcppBanner.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/gfcppBanner.cpp b/src/cppcache/src/gfcppBanner.cpp
index 42ae3d0..46c7623 100644
--- a/src/cppcache/src/gfcppBanner.cpp
+++ b/src/cppcache/src/gfcppBanner.cpp
@@ -1,5 +1,5 @@
 #include "gfcppBanner.hpp"
-using namespace gemfire;
+using namespace apache::geode::client;
 std::string gfcppBanner::getBanner() {
   std::string str =
       
"------------------------------------------------------------------------"

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/gfcppBanner.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/gfcppBanner.hpp b/src/cppcache/src/gfcppBanner.hpp
index f0c052f..9af0eb3 100644
--- a/src/cppcache/src/gfcppBanner.hpp
+++ b/src/cppcache/src/gfcppBanner.hpp
@@ -16,9 +16,13 @@
  */
 
 #include <string>
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class gfcppBanner {
  public:
   static std::string getBanner();
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp 
b/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
index 8d9c30d..5f7313a 100644
--- a/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
+++ b/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
@@ -28,7 +28,7 @@
 
 #include <NonCopyable.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp 
b/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
index 812049f..83e32e5 100644
--- a/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
+++ b/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
@@ -30,7 +30,7 @@
 #include "OsStatisticsImpl.hpp"
 #include "HostStatHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace gemfire_statistics;
 
 /**

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp 
b/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
index 1240f90..ac1ef0f 100644
--- a/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
+++ b/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
@@ -32,7 +32,7 @@
 #include "StatisticsManager.hpp"
 #include <gfcpp/ExceptionTypes.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/HostStatSampler.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatSampler.cpp 
b/src/cppcache/src/statistics/HostStatSampler.cpp
index 15d3d89..e1e56b8 100644
--- a/src/cppcache/src/statistics/HostStatSampler.cpp
+++ b/src/cppcache/src/statistics/HostStatSampler.cpp
@@ -39,7 +39,7 @@
 #include <ClientHealthStats.hpp>
 #include <ClientProxyMembershipID.hpp>
 using namespace gemfire_statistics;
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace gemfire_stats_globals {
 std::string g_statFile;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/HostStatSampler.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatSampler.hpp 
b/src/cppcache/src/statistics/HostStatSampler.hpp
index 0926d05..acb5c1e 100644
--- a/src/cppcache/src/statistics/HostStatSampler.hpp
+++ b/src/cppcache/src/statistics/HostStatSampler.hpp
@@ -33,7 +33,7 @@
 
 #include <NonCopyable.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/LinuxProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/LinuxProcessStats.hpp 
b/src/cppcache/src/statistics/LinuxProcessStats.hpp
index 529ceb6..8596b15 100644
--- a/src/cppcache/src/statistics/LinuxProcessStats.hpp
+++ b/src/cppcache/src/statistics/LinuxProcessStats.hpp
@@ -23,7 +23,7 @@
 #include "ProcessStats.hpp"
 #include "HostStatHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/NullProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/NullProcessStats.hpp 
b/src/cppcache/src/statistics/NullProcessStats.hpp
index 6f13cf2..95f5f57 100644
--- a/src/cppcache/src/statistics/NullProcessStats.hpp
+++ b/src/cppcache/src/statistics/NullProcessStats.hpp
@@ -23,7 +23,7 @@
 #include "ProcessStats.hpp"
 #include "HostStatHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
  */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/OsStatisticsImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/OsStatisticsImpl.hpp 
b/src/cppcache/src/statistics/OsStatisticsImpl.hpp
index f2cf9e0..ba1605a 100644
--- a/src/cppcache/src/statistics/OsStatisticsImpl.hpp
+++ b/src/cppcache/src/statistics/OsStatisticsImpl.hpp
@@ -22,7 +22,7 @@
 #include <gfcpp/statistics/StatisticsFactory.hpp>
 #include <NonCopyable.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/PoolStatsSampler.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/PoolStatsSampler.cpp 
b/src/cppcache/src/statistics/PoolStatsSampler.cpp
index ed28c48..7e729a6 100644
--- a/src/cppcache/src/statistics/PoolStatsSampler.cpp
+++ b/src/cppcache/src/statistics/PoolStatsSampler.cpp
@@ -24,7 +24,7 @@
 #include <NanoTimer.hpp>
 #include "HostStatHelper.hpp"
 using namespace gemfire_statistics;
-using namespace gemfire;
+using namespace apache::geode::client;
 const char* PoolStatsSampler::NC_PSS_Thread = "NC PSS Thread";
 
 PoolStatsSampler::PoolStatsSampler(int64 sampleRate, CacheImpl* cache,

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/PoolStatsSampler.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/PoolStatsSampler.hpp 
b/src/cppcache/src/statistics/PoolStatsSampler.hpp
index d176335..1c69bab 100644
--- a/src/cppcache/src/statistics/PoolStatsSampler.hpp
+++ b/src/cppcache/src/statistics/PoolStatsSampler.hpp
@@ -18,13 +18,17 @@
 #define __POOLSTATSSAMPLER__
 #include <ace/Task.h>
 #include <gfcpp/gfcpp_globals.hpp>
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class CacheImpl;
 class ThinClientBaseDM;
 class AdminRegion;
 class ThinClientPoolDM;
-}  // namespace gemfire
-using namespace gemfire;
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
+using namespace apache::geode::client;
 namespace gemfire_statistics {
 class StatisticsManager;
 class CPPCACHE_EXPORT PoolStatsSampler : public ACE_Task_Base {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/ProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/ProcessStats.hpp 
b/src/cppcache/src/statistics/ProcessStats.hpp
index f6f68f7..24010aa 100644
--- a/src/cppcache/src/statistics/ProcessStats.hpp
+++ b/src/cppcache/src/statistics/ProcessStats.hpp
@@ -20,7 +20,7 @@
 
 #include <gfcpp/gfcpp_globals.hpp>
 #include <gfcpp/statistics/Statistics.hpp>
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/SolarisProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/SolarisProcessStats.hpp 
b/src/cppcache/src/statistics/SolarisProcessStats.hpp
index f67d534..c8644f4 100644
--- a/src/cppcache/src/statistics/SolarisProcessStats.hpp
+++ b/src/cppcache/src/statistics/SolarisProcessStats.hpp
@@ -23,7 +23,7 @@
 #include "ProcessStats.hpp"
 #include "HostStatHelper.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/StatArchiveWriter.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatArchiveWriter.cpp 
b/src/cppcache/src/statistics/StatArchiveWriter.cpp
index d950b1c..066059e 100644
--- a/src/cppcache/src/statistics/StatArchiveWriter.cpp
+++ b/src/cppcache/src/statistics/StatArchiveWriter.cpp
@@ -28,7 +28,7 @@
 #include "GemfireStatisticsFactory.hpp"
 #include <NanoTimer.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace gemfire_statistics;
 
 // Constructor and Member functions of StatDataOutput class

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/StatArchiveWriter.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatArchiveWriter.hpp 
b/src/cppcache/src/statistics/StatArchiveWriter.hpp
index 85b1215..1efd760 100644
--- a/src/cppcache/src/statistics/StatArchiveWriter.hpp
+++ b/src/cppcache/src/statistics/StatArchiveWriter.hpp
@@ -32,7 +32,7 @@
 #include <gfcpp/DataOutput.hpp>
 #include <NonCopyable.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /**
  * some constants to be used while archiving

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/StatSamplerStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatSamplerStats.hpp 
b/src/cppcache/src/statistics/StatSamplerStats.hpp
index 5d44171..a2650f9 100644
--- a/src/cppcache/src/statistics/StatSamplerStats.hpp
+++ b/src/cppcache/src/statistics/StatSamplerStats.hpp
@@ -23,7 +23,7 @@
 #include <gfcpp/statistics/Statistics.hpp>
 #include <gfcpp/statistics/StatisticsFactory.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp 
b/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
index d0f6bd3..948d109 100644
--- a/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
+++ b/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
@@ -204,8 +204,9 @@ const char* StatisticDescriptorImpl::getUnit() { return 
unit.c_str(); }
 
 /* adongre
  * CID 28912: Uncaught exception (UNCAUGHT_EXCEPT)An exception of type
- * "gemfire::IllegalStateException *"
- * is thrown but the throw list "throw (gemfire::IllegalArgumentException)"
+ * "apache::geode::client::IllegalStateException *"
+ * is thrown but the throw list "throw
+ * (apache::geode::client::IllegalArgumentException)"
  * doesn't allow it to be thrown.
  * This will cause a call to unexpected() which usually calls terminate().
  */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/StatisticsManager.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsManager.cpp 
b/src/cppcache/src/statistics/StatisticsManager.cpp
index 4b059ad..743c9df 100644
--- a/src/cppcache/src/statistics/StatisticsManager.cpp
+++ b/src/cppcache/src/statistics/StatisticsManager.cpp
@@ -32,7 +32,7 @@
 #include "AtomicStatisticsImpl.hpp"
 #include "OsStatisticsImpl.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 using namespace gemfire_statistics;
 
 /**

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/src/statistics/WindowsProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/WindowsProcessStats.hpp 
b/src/cppcache/src/statistics/WindowsProcessStats.hpp
index fa6874e..bd6536e 100644
--- a/src/cppcache/src/statistics/WindowsProcessStats.hpp
+++ b/src/cppcache/src/statistics/WindowsProcessStats.hpp
@@ -24,7 +24,7 @@
 #include "ProcessStats.hpp"
 #include <gfcpp/ExceptionTypes.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 /** @file
 */

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/AutoDeleteTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/AutoDeleteTest.cpp 
b/src/cppcache/test/AutoDeleteTest.cpp
index 922c083..59c6f38 100644
--- a/src/cppcache/test/AutoDeleteTest.cpp
+++ b/src/cppcache/test/AutoDeleteTest.cpp
@@ -20,7 +20,7 @@
 #include <gfcpp/SharedBase.hpp>
 #include <AutoDelete.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace {
 class TestSharedBase : public SharedBase {
@@ -39,7 +39,7 @@ class TestSharedBase : public SharedBase {
 TEST(AutoDeleteTest, DestructorDoesDeleteByDefault) {
   bool destructed = false;
   TestSharedBase* ptr = new TestSharedBase(destructed);
-  { gemfire::DeleteObject<TestSharedBase> obj(ptr); }
+  { apache::geode::client::DeleteObject<TestSharedBase> obj(ptr); }
   EXPECT_EQ(true, destructed);
 }
 
@@ -47,7 +47,7 @@ TEST(AutoDeleteTest, DestructorDoesNotDeleteWhenAsked) {
   bool destructed = false;
   TestSharedBase* ptr = new TestSharedBase(destructed);
   {
-    gemfire::DeleteObject<TestSharedBase> obj(ptr);
+    apache::geode::client::DeleteObject<TestSharedBase> obj(ptr);
     obj.noDelete();
   }
   EXPECT_EQ(false, destructed);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ByteArray.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ByteArray.cpp b/src/cppcache/test/ByteArray.cpp
index b1e8184..0381ac1 100644
--- a/src/cppcache/test/ByteArray.cpp
+++ b/src/cppcache/test/ByteArray.cpp
@@ -39,7 +39,9 @@ std::string convertWstringToString(const wchar_t* wstr) {
 }
 }  // namespace
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 ByteArray ByteArray::fromString(const std::string& str) {
   ByteArray ba;
   if (!str.empty()) {
@@ -123,4 +125,6 @@ ByteArray& ByteArray::operator=(const ByteArray& other) {
 }
 
 std::string ByteArray::toString() const { return toString(*this); }
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ByteArray.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ByteArray.hpp b/src/cppcache/test/ByteArray.hpp
index a5d0d40..849a58e 100644
--- a/src/cppcache/test/ByteArray.hpp
+++ b/src/cppcache/test/ByteArray.hpp
@@ -21,7 +21,9 @@
 #include <memory>
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 class ByteArray {
  public:
   static ByteArray fromString(const std::string &str);
@@ -54,4 +56,6 @@ class ByteArray {
   std::shared_ptr<uint8_t> m_bytes;
   std::size_t m_size;
 };
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ByteArrayFixture.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ByteArrayFixture.cpp 
b/src/cppcache/test/ByteArrayFixture.cpp
index 0a0d629..08c3063 100644
--- a/src/cppcache/test/ByteArrayFixture.cpp
+++ b/src/cppcache/test/ByteArrayFixture.cpp
@@ -19,9 +19,9 @@
 
 ::testing::AssertionResult ByteArrayFixture::assertByteArrayEqual(
     const char* expectedStr, const char* bytesStr, const char* expected,
-    const gemfire::ByteArray& bytes) {
+    const apache::geode::client::ByteArray& bytes) {
   // One would normally just use std::regex but gcc 4.4.7 is lacking.
-  const std::string actual(gemfire::ByteArray::toString(bytes));
+  const std::string actual(apache::geode::client::ByteArray::toString(bytes));
   std::string::size_type actualPos = 0;
   const std::string pattern(expected);
   std::string::size_type patternPos = 0;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ByteArrayFixture.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ByteArrayFixture.hpp 
b/src/cppcache/test/ByteArrayFixture.hpp
index c396bc6..4767dc0 100644
--- a/src/cppcache/test/ByteArrayFixture.hpp
+++ b/src/cppcache/test/ByteArrayFixture.hpp
@@ -28,5 +28,5 @@ class ByteArrayFixture {
  public:
   ::testing::AssertionResult assertByteArrayEqual(
       const char* expectedStr, const char* bytesStr, const char* expected,
-      const gemfire::ByteArray& bytes);
+      const apache::geode::client::ByteArray& bytes);
 };

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ByteArrayTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ByteArrayTest.cpp 
b/src/cppcache/test/ByteArrayTest.cpp
index c7ebcfc..ac91599 100644
--- a/src/cppcache/test/ByteArrayTest.cpp
+++ b/src/cppcache/test/ByteArrayTest.cpp
@@ -17,7 +17,7 @@
 
 #include "ByteArrayFixture.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(ByteArrayTest, TestNoArgConstructor) {
   const ByteArray ba;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/CacheXmlParserTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/CacheXmlParserTest.cpp 
b/src/cppcache/test/CacheXmlParserTest.cpp
index a3615d0..59dd705 100644
--- a/src/cppcache/test/CacheXmlParserTest.cpp
+++ b/src/cppcache/test/CacheXmlParserTest.cpp
@@ -19,7 +19,7 @@
 
 #include <CacheXmlParser.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 std::string xsd_prefix = R"(<?xml version='1.0' encoding='UTF-8'?>
 <client-cache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/CacheableKeysTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/CacheableKeysTest.cpp 
b/src/cppcache/test/CacheableKeysTest.cpp
index 4280cb5..02dcd13 100644
--- a/src/cppcache/test/CacheableKeysTest.cpp
+++ b/src/cppcache/test/CacheableKeysTest.cpp
@@ -19,7 +19,7 @@
 
 #include <gfcpp/CacheableKeys.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(CacheableKeysTest, boolDifferentHashCodes) {
   EXPECT_NE(serializer::hashcode(false), serializer::hashcode(true))

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/DataInputTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/DataInputTest.cpp 
b/src/cppcache/test/DataInputTest.cpp
index 962be6c..6641e4e 100644
--- a/src/cppcache/test/DataInputTest.cpp
+++ b/src/cppcache/test/DataInputTest.cpp
@@ -28,7 +28,7 @@
 #include <gfcpp/SharedPtr.hpp>
 #include "ByteArrayFixture.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class TestDataInput {
  public:
@@ -197,7 +197,8 @@ TEST_F(DataInputTest, ThrowsWhenReadingInputWithSizeZero) {
   TestDataInput dataInput("");
 
   uint8_t aByte = 0U;
-  ASSERT_THROW(dataInput.read(&aByte), gemfire::OutOfRangeException);
+  ASSERT_THROW(dataInput.read(&aByte),
+               apache::geode::client::OutOfRangeException);
 }
 
 TEST_F(DataInputTest, ThrowsWhenReadingMoreBytesThanSizePassedToConstructor) {
@@ -208,7 +209,8 @@ TEST_F(DataInputTest, 
ThrowsWhenReadingMoreBytesThanSizePassedToConstructor) {
   EXPECT_EQ(1U, aByte);
 
   aByte = 0U;
-  ASSERT_THROW(dataInput.read(&aByte), gemfire::OutOfRangeException);
+  ASSERT_THROW(dataInput.read(&aByte),
+               apache::geode::client::OutOfRangeException);
 }
 
 TEST_F(DataInputTest, CanReadUnsignedBytesFromInput) {
@@ -265,7 +267,7 @@ TEST_F(DataInputTest,
   // fails to read 4 bytes from 3 byte buffer
   uint8_t byteArrayCopy[4];
   ASSERT_THROW(dataInput.readBytesOnly(byteArrayCopy, 4),
-               gemfire::OutOfRangeException);
+               apache::geode::client::OutOfRangeException);
 }
 
 TEST_F(DataInputTest, CanReadIntWithAMaxSizeUnsigned64BitIntInput) {
@@ -299,7 +301,7 @@ TEST_F(DataInputTest, 
ThrowsWhenCallingReadStringWithAnASCIIStringInput) {
 
   // ASCII and non-ASCII: consider matching exception string
   ASSERT_THROW(dataInput.readString(&actualString),
-               gemfire::IllegalArgumentException);
+               apache::geode::client::IllegalArgumentException);
 }
 
 TEST_F(DataInputTest, CanReadASCIIWithAnUTFStringInput) {
@@ -324,7 +326,7 @@ TEST_F(DataInputTest, 
ThrowsWhenCallingReadStringWithAnUTFStringInput) {
 
   // UTF and non-UTF: consider matching exception string
   ASSERT_THROW(dataInput.readString(&actualString),
-               gemfire::IllegalArgumentException);
+               apache::geode::client::IllegalArgumentException);
 }
 
 TEST_F(DataInputTest, CanReadUTFWithAnUTFStringInput) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/DataOutputTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/DataOutputTest.cpp 
b/src/cppcache/test/DataOutputTest.cpp
index c76c8e2..f7dfa4c 100644
--- a/src/cppcache/test/DataOutputTest.cpp
+++ b/src/cppcache/test/DataOutputTest.cpp
@@ -24,7 +24,7 @@
 #include <gfcpp/DataOutput.hpp>
 #include "ByteArrayFixture.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class TestDataOutput : public DataOutput {
  public:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/DiskPolicyTypeTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/DiskPolicyTypeTest.cpp 
b/src/cppcache/test/DiskPolicyTypeTest.cpp
index df6cc3a..b368828 100644
--- a/src/cppcache/test/DiskPolicyTypeTest.cpp
+++ b/src/cppcache/test/DiskPolicyTypeTest.cpp
@@ -19,7 +19,7 @@
 
 #include <gfcpp/DiskPolicyType.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(DiskPolicyTypeTest, VerifyOrdinalAndNameSymmetryForNone) {
   const char* name = DiskPolicyType::fromOrdinal(0);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/ExpirationActionTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/ExpirationActionTest.cpp 
b/src/cppcache/test/ExpirationActionTest.cpp
index 58da11a..aa33fa3 100644
--- a/src/cppcache/test/ExpirationActionTest.cpp
+++ b/src/cppcache/test/ExpirationActionTest.cpp
@@ -19,7 +19,7 @@
 
 #include <gfcpp/ExpirationAction.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(ExpirationActionTest, VerifyOrdinalAndNameSymmetryForInvalidate) {
   const char* name = ExpirationAction::fromOrdinal(0);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/InterestResultPolicyTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/InterestResultPolicyTest.cpp 
b/src/cppcache/test/InterestResultPolicyTest.cpp
index 4bbc250..3739646 100644
--- a/src/cppcache/test/InterestResultPolicyTest.cpp
+++ b/src/cppcache/test/InterestResultPolicyTest.cpp
@@ -19,7 +19,7 @@
 
 #include <InterestResultPolicy.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(InterestResultPolicyTest, VerifyOrdinals) {
   EXPECT_NE(InterestResultPolicy::NONE.getOrdinal(),

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/NanoTimerTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/NanoTimerTest.cpp 
b/src/cppcache/test/NanoTimerTest.cpp
index 614bd2a..7c10ab5 100644
--- a/src/cppcache/test/NanoTimerTest.cpp
+++ b/src/cppcache/test/NanoTimerTest.cpp
@@ -19,7 +19,7 @@
 
 #include <NanoTimer.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(NanoTimerTest, ValidateSleep) {
   const int64_t before = NanoTimer::now();

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/PdxLocalReaderTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/PdxLocalReaderTest.cpp 
b/src/cppcache/test/PdxLocalReaderTest.cpp
index efdcae7..5b63ad3 100644
--- a/src/cppcache/test/PdxLocalReaderTest.cpp
+++ b/src/cppcache/test/PdxLocalReaderTest.cpp
@@ -22,7 +22,7 @@
 #include <PdxLocalWriter.hpp>
 #include <PdxTypeRegistry.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class MyPdxClass : public PdxSerializable {
  public:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/SharedBaseTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/SharedBaseTest.cpp 
b/src/cppcache/test/SharedBaseTest.cpp
index aa200a6..2b2a3d5 100644
--- a/src/cppcache/test/SharedBaseTest.cpp
+++ b/src/cppcache/test/SharedBaseTest.cpp
@@ -19,7 +19,7 @@
 
 #include <gfcpp/SharedBase.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 namespace {
 class TestSharedBase : public SharedBase {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/SharedPtrTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/SharedPtrTest.cpp 
b/src/cppcache/test/SharedPtrTest.cpp
index dd1c71c..99d3b9d 100644
--- a/src/cppcache/test/SharedPtrTest.cpp
+++ b/src/cppcache/test/SharedPtrTest.cpp
@@ -21,7 +21,7 @@
 
 #include <gfcpp/SharedPtr.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class NotifyOnDelete : public SharedBase {
  public:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/TcrMessage_unittest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/TcrMessage_unittest.cpp 
b/src/cppcache/test/TcrMessage_unittest.cpp
index ddcc26e..c18829b 100644
--- a/src/cppcache/test/TcrMessage_unittest.cpp
+++ b/src/cppcache/test/TcrMessage_unittest.cpp
@@ -22,7 +22,7 @@
 #include <TcrMessage.hpp>
 #include "ByteArrayFixture.hpp"
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 #define EXPECT_MESSAGE_EQ(e, a) EXPECT_PRED_FORMAT2(assertMessageEqual, e, a)
 
@@ -30,8 +30,8 @@ class TcrMessageTest : public ::testing::Test, protected 
ByteArrayFixture {
  public:
   ::testing::AssertionResult assertMessageEqual(
       const char *expectedStr, const char *bytesStr, const char *expected,
-      const gemfire::TcrMessage &msg) {
-    gemfire::ByteArray bytes(
+      const apache::geode::client::TcrMessage &msg) {
+    apache::geode::client::ByteArray bytes(
         reinterpret_cast<const uint8_t *>(msg.getMsgData()),
         static_cast<const std::size_t>(msg.getMsgLength()));
     return ByteArrayFixture::assertByteArrayEqual(expectedStr, bytesStr,

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/cppcache/test/gfcppBannerTest.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/test/gfcppBannerTest.cpp 
b/src/cppcache/test/gfcppBannerTest.cpp
index f8e7710..e3d7857 100644
--- a/src/cppcache/test/gfcppBannerTest.cpp
+++ b/src/cppcache/test/gfcppBannerTest.cpp
@@ -19,7 +19,7 @@
 
 #include <gfcppBanner.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 TEST(gfcppBannerTest, ValidateBanner) {
   EXPECT_LT(0, gfcppBanner::getBanner().size()) << "Non-empty banner";

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/gfcpp/gfcpp.cpp
----------------------------------------------------------------------
diff --git a/src/gfcpp/gfcpp.cpp b/src/gfcpp/gfcpp.cpp
index a40fea1..8384fa3 100644
--- a/src/gfcpp/gfcpp.cpp
+++ b/src/gfcpp/gfcpp.cpp
@@ -22,7 +22,7 @@
 #include <gfcpp/ExceptionTypes.hpp>
 #include <gfcpp/CacheFactory.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 void doVersion() { printf("\n%s\n", CacheFactory::getProductDescription()); }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/ASBuiltins.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/ASBuiltins.hpp 
b/src/pdxautoserializer/ASBuiltins.hpp
index 5036e05..5ec3381 100644
--- a/src/pdxautoserializer/ASBuiltins.hpp
+++ b/src/pdxautoserializer/ASBuiltins.hpp
@@ -25,15 +25,19 @@
 #include <vector>
 #include <map>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace serializer {
 /** write an <code>std::string</code> object to <code>DataOutput</code> */
-inline void writeObject(gemfire::DataOutput& output, const std::string& value) 
{
+inline void writeObject(apache::geode::client::DataOutput& output,
+                        const std::string& value) {
   output.writeASCIIHuge(value.data(), value.length());
 }
 
 /** read an <code>std::string</code> object from <code>DataInput</code> */
-inline void readObject(gemfire::DataInput& input, std::string& value) {
+inline void readObject(apache::geode::client::DataInput& input,
+                       std::string& value) {
   char* str;
   uint32_t len;
   input.readASCIIHuge(&str, &len);
@@ -42,13 +46,14 @@ inline void readObject(gemfire::DataInput& input, 
std::string& value) {
 }
 
 /** write an <code>std::wstring</code> object to <code>DataOutput</code> */
-inline void writeObject(gemfire::DataOutput& output,
+inline void writeObject(apache::geode::client::DataOutput& output,
                         const std::wstring& value) {
   output.writeUTFHuge(value.data(), value.length());
 }
 
 /** read an <code>std::wstring</code> object from <code>DataInput</code> */
-inline void readObject(gemfire::DataInput& input, std::wstring& value) {
+inline void readObject(apache::geode::client::DataInput& input,
+                       std::wstring& value) {
   wchar_t* str;
   uint32_t len;
   input.readUTFHuge(&str, &len);
@@ -58,7 +63,7 @@ inline void readObject(gemfire::DataInput& input, 
std::wstring& value) {
 
 /** write an <code>std::vector</code> object to <code>DataOutput</code> */
 template <typename TObj>
-inline void writeObject(gemfire::DataOutput& output,
+inline void writeObject(apache::geode::client::DataOutput& output,
                         const std::vector<TObj>& value) {
   output.writeInt(value.size());
   for (std::vector<TObj>::const_iterator valIterator = value.begin();
@@ -69,7 +74,8 @@ inline void writeObject(gemfire::DataOutput& output,
 
 /** read an <code>std::vector</code> object from <code>DataInput</code> */
 template <typename TObj>
-inline void readObject(gemfire::DataInput& input, std::vector<TObj>& value) {
+inline void readObject(apache::geode::client::DataInput& input,
+                       std::vector<TObj>& value) {
   std::vector<TObj>::size_type len;
   input.readInt(&len);
   if (len > 0) {
@@ -83,7 +89,7 @@ inline void readObject(gemfire::DataInput& input, 
std::vector<TObj>& value) {
 
 /** write an <code>std::map</code> object to <code>DataOutput</code> */
 template <typename TKey, typename TVal>
-inline void writeObject(gemfire::DataOutput& output,
+inline void writeObject(apache::geode::client::DataOutput& output,
                         const std::map<TKey, TVal>& value) {
   output.writeInt(value.size());
   for (std::map<TKey, TVal>::const_iterator valIterator = value.begin();
@@ -95,7 +101,8 @@ inline void writeObject(gemfire::DataOutput& output,
 
 /** read an <code>std::map</code> object from <code>DataInput</code> */
 template <typename TKey, typename TVal>
-inline void readObject(gemfire::DataInput& input, std::map<TKey, TVal>& value) 
{
+inline void readObject(apache::geode::client::DataInput& input,
+                       std::map<TKey, TVal>& value) {
   std::map<TKey, TVal>::size_type len;
   input.readInt(&len);
   if (len > 0) {
@@ -110,5 +117,7 @@ inline void readObject(gemfire::DataInput& input, 
std::map<TKey, TVal>& value) {
 }
 }
 }
+}
+}
 
 #endif  // _GFAS_ASBUILTINS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/ASCLIBuiltins.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/ASCLIBuiltins.hpp 
b/src/pdxautoserializer/ASCLIBuiltins.hpp
index 3f018fa..c1c3191 100644
--- a/src/pdxautoserializer/ASCLIBuiltins.hpp
+++ b/src/pdxautoserializer/ASCLIBuiltins.hpp
@@ -88,27 +88,29 @@ struct YesNoType<false> {
 #define TYPE_IS_IGFSERIALIZABLE_TYPE(T) \
   TypeHelper::YesNoType<TYPE_IS_SERIALIZABLE(T)>::value
 
-inline void WriteObject(gemfire::DataOutput& output, Byte value) {
+inline void WriteObject(apache::geode::client::DataOutput& output, Byte value) 
{
   output.write((uint8_t)value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Byte % value) {
+inline void ReadObject(apache::geode::client::DataInput& input, Byte % value) {
   uint8_t val;
   input.read(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, SByte value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        SByte value) {
   output.write((int8_t)value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, SByte % value) {
+inline void ReadObject(apache::geode::client::DataInput& input, SByte % value) 
{
   int8_t val;
   input.read(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, array<Byte> ^ bytes) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        array<Byte> ^ bytes) {
   if (bytes != nullptr) {
     // We can safely use the pinning technique here since the pointer
     // is not required after the end of native 'writeBytes' function.
@@ -119,7 +121,8 @@ inline void WriteObject(gemfire::DataOutput& output, 
array<Byte> ^ bytes) {
   }
 }
 
-inline void ReadObject(gemfire::DataInput& input, array<Byte> ^ % bytes) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       array<Byte> ^ % bytes) {
   int32_t length;
   input.readInt(&length);
   if (length > 0) {
@@ -131,7 +134,8 @@ inline void ReadObject(gemfire::DataInput& input, 
array<Byte> ^ % bytes) {
   }
 }
 
-inline void WriteObject(gemfire::DataOutput& output, array<SByte> ^ bytes) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        array<SByte> ^ bytes) {
   if (bytes != nullptr) {
     pin_ptr<SByte> pin_bytes = &bytes[0];
     output.writeBytes((int8_t*)pin_bytes, bytes->Length);
@@ -140,7 +144,8 @@ inline void WriteObject(gemfire::DataOutput& output, 
array<SByte> ^ bytes) {
   }
 }
 
-inline void ReadObject(gemfire::DataInput& input, array<SByte> ^ % bytes) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       array<SByte> ^ % bytes) {
   int32_t length;
   input.readInt(&length);
   if (length > 0) {
@@ -152,97 +157,113 @@ inline void ReadObject(gemfire::DataInput& input, 
array<SByte> ^ % bytes) {
   }
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Int16 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Int16 value) {
   output.writeInt((int16_t)value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Int16 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input, Int16 % value) 
{
   int16_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Int32 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Int32 value) {
   output.writeInt(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Int32 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input, Int32 % value) 
{
   int32_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Int64 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Int64 value) {
   output.writeInt(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Int64 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input, Int64 % value) 
{
   int64_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, UInt16 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        UInt16 value) {
   output.writeInt(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, UInt16 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       UInt16 % value) {
   uint16_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, UInt32 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        UInt32 value) {
   output.writeInt(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, UInt32 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       UInt32 % value) {
   uint32_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, UInt64 value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        UInt64 value) {
   output.writeInt(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, UInt64 % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       UInt64 % value) {
   uint64_t val;
   input.readInt(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Boolean value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Boolean value) {
   output.write((uint8_t)(value ? 1 : 0));
 }
 
-inline void ReadObject(gemfire::DataInput& input, Boolean % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       Boolean % value) {
   uint8_t byte;
   input.read(&byte);
   value = (byte == 1 ? true : false);
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Double value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Double value) {
   output.writeDouble(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Double % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       Double % value) {
   double val;
   input.readDouble(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, Single value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        Single value) {
   output.writeFloat(value);
 }
 
-inline void ReadObject(gemfire::DataInput& input, Single % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       Single % value) {
   float val;
   input.readFloat(&val);
   value = val;
 }
 
-inline void WriteObject(gemfire::DataOutput& output, String ^ str) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        String ^ str) {
   if (str != nullptr) {
     pin_ptr<const wchar_t> pin_str = PtrToStringChars(str);
     output.writeUTF((wchar_t*)pin_str, str->Length);
@@ -251,7 +272,8 @@ inline void WriteObject(gemfire::DataOutput& output, String 
^ str) {
   }
 }
 
-inline void ReadObject(gemfire::DataInput& input, String ^ % str) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       String ^ % str) {
   wchar_t* n_buffer = nullptr;
   uint16_t len;
   input.readUTF(&n_buffer, &len);
@@ -264,79 +286,86 @@ inline void ReadObject(gemfire::DataInput& input, String 
^ % str) {
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        TObj ^ value, TypeHelper::yes_type isSerializable) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, TObj ^ value,
+                        TypeHelper::yes_type isSerializable) {
   mg_output->WriteObject(value);
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        TObj ^ value, TypeHelper::no_type isNotSerializable) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, TObj ^ value,
+                        TypeHelper::no_type isNotSerializable) {
   WriteObject(output, value);
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        TObj ^ value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, TObj ^ value) {
   WriteObject(output, mg_output, value, TYPE_IS_IGFSERIALIZABLE_TYPE(TObj));
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        TObj value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, TObj value) {
   WriteObject(output, value);
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       TObj ^ % value, TypeHelper::yes_type isSerializable) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, TObj ^ % value,
+                       TypeHelper::yes_type isSerializable) {
   value = static_cast<TObj ^>(mg_input->ReadObject());
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       TObj ^ % value, TypeHelper::no_type isNotSerializable) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, TObj ^ % value,
+                       TypeHelper::no_type isNotSerializable) {
   ReadObject(input, value);
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       TObj ^ % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, TObj ^ % value) {
   ReadObject(input, mg_input, value, TYPE_IS_IGFSERIALIZABLE_TYPE(TObj));
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       TObj % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, TObj % value) {
   ReadObject(input, value);
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, array<TObj> ^ arr) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        array<TObj> ^ arr) {
   if (arr != nullptr) {
     pin_ptr<TObj> pin_arr = &arr[0];
-    gemfire::serializer::writeObject(output, (TObj*)pin_arr, arr->Length);
+    apache::geode::client::serializer::writeObject(output, (TObj*)pin_arr,
+                                                   arr->Length);
   } else {
     output.writeInt(0);
   }
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, array<TObj> ^ % arr) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       array<TObj> ^ % arr) {
   int32_t size;
   input.readInt(&size);
   if (size > 0) {
     arr = gcnew array<TObj>(size);
     pin_ptr<TObj> pin_arr = &arr[0];
-    gemfire::serializer::readArray(input, (TObj*)pin_arr, size);
+    apache::geode::client::serializer::readArray(input, (TObj*)pin_arr, size);
   } else {
     arr = nullptr;
   }
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        array<TObj ^> ^ arr) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, array<TObj ^> ^ arr) {
   if (arr != nullptr) {
     output.writeInt(arr->Length);
             for
@@ -347,8 +376,8 @@ inline void WriteObject(gemfire::DataOutput& output, 
DataOutput ^ mg_output,
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       array<TObj ^> ^ % arr) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, array<TObj ^> ^ % arr) {
   int32_t size;
   input.readInt(&size);
   if (size > 0) {
@@ -361,8 +390,8 @@ inline void ReadObject(gemfire::DataInput& input, DataInput 
^ mg_input,
 }
 
 template <typename TObj>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
-                        List<TObj> ^ value) {
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output, List<TObj> ^ value) {
   if (value != nullptr) {
     output.writeInt(value->Count);
             for
@@ -373,8 +402,8 @@ inline void WriteObject(gemfire::DataOutput& output, 
DataOutput ^ mg_output,
 }
 
 template <typename TObj>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       List<TObj> ^ % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, List<TObj> ^ % value) {
   int32_t len;
   input.readInt(&len);
   if (len > 0) {
@@ -388,7 +417,8 @@ inline void ReadObject(gemfire::DataInput& input, DataInput 
^ mg_input,
 }
 
 template <typename TKey, typename TVal>
-inline void WriteObject(gemfire::DataOutput& output, DataOutput ^ mg_output,
+inline void WriteObject(apache::geode::client::DataOutput& output,
+                        DataOutput ^ mg_output,
                         Dictionary<TKey, TVal> ^ value) {
   if (value != nullptr) {
     output.writeInt(value->Count);
@@ -403,8 +433,8 @@ inline void WriteObject(gemfire::DataOutput& output, 
DataOutput ^ mg_output,
 }
 
 template <typename TKey, typename TVal>
-inline void ReadObject(gemfire::DataInput& input, DataInput ^ mg_input,
-                       Dictionary<TKey, TVal> ^ % value) {
+inline void ReadObject(apache::geode::client::DataInput& input,
+                       DataInput ^ mg_input, Dictionary<TKey, TVal> ^ % value) 
{
   int32_t len;
   input.readInt(&len);
   if (len > 0) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/CodeGenerator.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/CodeGenerator.hpp 
b/src/pdxautoserializer/CodeGenerator.hpp
index 8555ffa..6df1342 100644
--- a/src/pdxautoserializer/CodeGenerator.hpp
+++ b/src/pdxautoserializer/CodeGenerator.hpp
@@ -20,7 +20,9 @@
 
 #include "base_types.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * Abstract class that defines the interface of the auto-serializer
@@ -165,7 +167,9 @@ class CodeGenerator {
 
   // End pure virtual methods
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_CODEGENERATOR_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/CodeGeneratorFactory.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/CodeGeneratorFactory.cpp 
b/src/pdxautoserializer/CodeGeneratorFactory.cpp
index ed7eb1d..36d32bc 100644
--- a/src/pdxautoserializer/CodeGeneratorFactory.cpp
+++ b/src/pdxautoserializer/CodeGeneratorFactory.cpp
@@ -21,7 +21,9 @@
 //#include "impl/CPPCLICodeGenerator.hpp"
 //#include "impl/CSharpCodeGenerator.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 CodeGeneratorFactory::CodeGeneratorFactory() {
   // Register the available code generators here.
@@ -53,4 +55,6 @@ StringVector CodeGeneratorFactory::getGenerators() const {
 
 CodeGeneratorFactory::~CodeGeneratorFactory() { m_generatorMap.clear(); }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/CodeGeneratorFactory.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/CodeGeneratorFactory.hpp 
b/src/pdxautoserializer/CodeGeneratorFactory.hpp
index 17d5754..48ffd8d 100644
--- a/src/pdxautoserializer/CodeGeneratorFactory.hpp
+++ b/src/pdxautoserializer/CodeGeneratorFactory.hpp
@@ -20,7 +20,9 @@
 
 #include "CodeGenerator.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * Defines a function with no arguments returning a pointer to
@@ -62,7 +64,9 @@ class CodeGeneratorFactory {
    */
   std::map<std::string, ASCodeGeneratorFn> m_generatorMap;
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_CODEGENERATORFACTORY_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/InputParser.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/InputParser.cpp 
b/src/pdxautoserializer/InputParser.cpp
index 193c151..67d2e83 100644
--- a/src/pdxautoserializer/InputParser.cpp
+++ b/src/pdxautoserializer/InputParser.cpp
@@ -18,7 +18,9 @@
 #include "base_types.hpp"
 #include "InputParser.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 // ClassInfo method definitions
 
@@ -49,4 +51,6 @@ bool InputParser::contains(const std::string& className) 
const {
   return (findClass != m_classes.end());
 }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/InputParser.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/InputParser.hpp 
b/src/pdxautoserializer/InputParser.hpp
index 096f41c..2092a22 100644
--- a/src/pdxautoserializer/InputParser.hpp
+++ b/src/pdxautoserializer/InputParser.hpp
@@ -21,7 +21,9 @@
 #include "base_types.hpp"
 #include "CodeGenerator.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 // Forward declaration.
 class InputParser;
@@ -172,7 +174,9 @@ class InputParser {
    */
   ASClassFlagMap m_classes;
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_INPUTPARSER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/InputParserFactory.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/InputParserFactory.cpp 
b/src/pdxautoserializer/InputParserFactory.cpp
index 8e12f90..a9dea87 100644
--- a/src/pdxautoserializer/InputParserFactory.cpp
+++ b/src/pdxautoserializer/InputParserFactory.cpp
@@ -26,7 +26,9 @@
 #include "impl/DotNetParser.hpp"
 #endif
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 InputParserFactory::InputParserFactory() {
   // Register the available parsers here.
@@ -59,4 +61,6 @@ StringVector InputParserFactory::getParsers() const {
 
 InputParserFactory::~InputParserFactory() { m_parserMap.clear(); }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/InputParserFactory.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/InputParserFactory.hpp 
b/src/pdxautoserializer/InputParserFactory.hpp
index d393eac..ac12b23 100644
--- a/src/pdxautoserializer/InputParserFactory.hpp
+++ b/src/pdxautoserializer/InputParserFactory.hpp
@@ -21,7 +21,9 @@
 #include "InputParser.hpp"
 #include <utility>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * Defines a function returning a pointer to an
@@ -64,7 +66,9 @@ class InputParserFactory {
    */
   std::map<std::string, InputParserFn> m_parserMap;
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_INPUTPARSERFACTORY_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/OutputFormatter.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/OutputFormatter.cpp 
b/src/pdxautoserializer/OutputFormatter.cpp
index 324f30d..a733389 100644
--- a/src/pdxautoserializer/OutputFormatter.cpp
+++ b/src/pdxautoserializer/OutputFormatter.cpp
@@ -19,7 +19,9 @@
 #include <cstring>
 #include <cerrno>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 // OutputFormatStreamBuf method definitions
 
@@ -142,4 +144,6 @@ void OutputFormatter::close() {
   m_ofstream.close();
 }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/OutputFormatter.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/OutputFormatter.hpp 
b/src/pdxautoserializer/OutputFormatter.hpp
index 2e55d4f..7f847d1 100644
--- a/src/pdxautoserializer/OutputFormatter.hpp
+++ b/src/pdxautoserializer/OutputFormatter.hpp
@@ -23,7 +23,9 @@
 #include <fstream>
 #include <string>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /** The default character to use for indentation. */
 const char DefaultIndentChar = ' ';
@@ -218,7 +220,9 @@ class OutputFormatter : public std::ostream {
   /** The formatter to use for formatting the output. */
   OutputFormatStreamBuf m_streamBuf;
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_OUTPUTFORMATTER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/base_types.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/CPPCodeGenerator.cpp 
b/src/pdxautoserializer/impl/CPPCodeGenerator.cpp
index 1f11ea6..1474473 100644
--- a/src/pdxautoserializer/impl/CPPCodeGenerator.cpp
+++ b/src/pdxautoserializer/impl/CPPCodeGenerator.cpp
@@ -21,12 +21,14 @@
 #include "Helper.hpp"
 #include <iostream>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 int CPPCodeGenerator::s_classId = -1;
 
 std::string CPPCodeGenerator::s_GFSerializerNamespace =
-    "gemfire::PdxAutoSerializable";
+    "apache::geode::client::PdxAutoSerializable";
 std::string CPPCodeGenerator::s_TempVarPrefix = "var_";
 
 /** The option name for classId. */
@@ -189,14 +191,16 @@ void CPPCodeGenerator::finishTryBlock(const Method::Type 
type) {
   switch (type) {
     case Method::TODATA: {
       *m_cppFormatter << "}\n";
-      *m_cppFormatter << "catch(gemfire::IllegalStateException exception)\n";
+      *m_cppFormatter
+          << "catch(apache::geode::client::IllegalStateException exception)\n";
       *m_cppFormatter << "{\n";
       *m_cppFormatter << "}\n";
       break;
     }
     case Method::FROMDATA: {
       *m_cppFormatter << "}\n";
-      *m_cppFormatter << "catch(gemfire::IllegalStateException exception)\n";
+      *m_cppFormatter
+          << "catch(apache::geode::client::IllegalStateException exception)\n";
       *m_cppFormatter << "{\n";
       *m_cppFormatter << "}\n";
       break;
@@ -216,14 +220,14 @@ void CPPCodeGenerator::startMethod(const Method::Type 
type,
 
   switch (type) {
     case Method::TODATA: {
-      varVec.push_back("gemfire::PdxWriterPtr __var");
+      varVec.push_back("apache::geode::client::PdxWriterPtr __var");
 
       genFunctionHeader("toData", className, "void", varVec, true, false,
                         m_cppFormatter, methodPrefix);
       break;
     }
     case Method::FROMDATA: {
-      varVec.push_back("gemfire::PdxReaderPtr __var ");
+      varVec.push_back("apache::geode::client::PdxReaderPtr __var ");
 
       genFunctionHeader("fromData", className, "void", varVec, true, false,
                         m_cppFormatter, methodPrefix);
@@ -346,8 +350,8 @@ void CPPCodeGenerator::genCreateDeserializable(
   StringVector varVec;
   std::string className = getTypeString(m_classInfo);
   genFunctionHeader("createDeserializable", className,
-                    "gemfire::PdxSerializable*", varVec, true, false,
-                    m_cppFormatter, methodPrefix);
+                    "apache::geode::client::PdxSerializable*", varVec, true,
+                    false, m_cppFormatter, methodPrefix);
   *m_cppFormatter << "return new " << className << "()"
                   << ";\n";
   genFunctionFooter(m_cppFormatter);
@@ -530,4 +534,6 @@ CPPCodeGenerator::~CPPCodeGenerator() {
   }
 }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/CPPCodeGenerator.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/CPPCodeGenerator.hpp 
b/src/pdxautoserializer/impl/CPPCodeGenerator.hpp
index a0cb2a0..4a150cf 100644
--- a/src/pdxautoserializer/impl/CPPCodeGenerator.hpp
+++ b/src/pdxautoserializer/impl/CPPCodeGenerator.hpp
@@ -21,7 +21,9 @@
 #include "../CodeGenerator.hpp"
 #include "../OutputFormatter.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * The C++ code generator backend.
@@ -227,7 +229,9 @@ class CPPCodeGenerator : public CodeGenerator {
    */
   static std::string s_GenSuffixOption;
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_CPPCODEGENERATOR_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/CPPParser/CPPInputParser.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/CPPParser/CPPInputParser.cpp 
b/src/pdxautoserializer/impl/CPPParser/CPPInputParser.cpp
index e1a3e40..b3507fe 100644
--- a/src/pdxautoserializer/impl/CPPParser/CPPInputParser.cpp
+++ b/src/pdxautoserializer/impl/CPPParser/CPPInputParser.cpp
@@ -35,7 +35,9 @@ void process_line_directive(const char* includedFile,
 
 ANTLR_USING_NAMESPACE(antlr);
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /** The name of this module to be used for logging. */
 static std::string ModuleName = "CPPInputParser";
@@ -312,4 +314,6 @@ InputParser* CPPInputParser::create() { return new 
CPPInputParser(); }
 
 CPPInputParser::~CPPInputParser() {}
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/CPPParser/CPPInputParser.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/CPPParser/CPPInputParser.hpp 
b/src/pdxautoserializer/impl/CPPParser/CPPInputParser.hpp
index 933fe52..030ff07 100644
--- a/src/pdxautoserializer/impl/CPPParser/CPPInputParser.hpp
+++ b/src/pdxautoserializer/impl/CPPParser/CPPInputParser.hpp
@@ -22,7 +22,9 @@
 #include "CPPLexer.hpp"
 #include "CPPParser.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 class CPPHeaderParser;
 
@@ -179,7 +181,9 @@ class CPPInputParser : public InputParser {
    */
   CPPInputParser();
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_CPPINPUTPARSER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/Helper.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/Helper.cpp 
b/src/pdxautoserializer/impl/Helper.cpp
index 7c6f7b2..edbea45 100644
--- a/src/pdxautoserializer/impl/Helper.cpp
+++ b/src/pdxautoserializer/impl/Helper.cpp
@@ -18,7 +18,9 @@
 #include "../base_types.hpp"
 #include "Helper.hpp"
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 void Helper::splitString(const std::string& str, const std::string& delim,
                          StringVector& splitStr) {
@@ -91,4 +93,6 @@ void Helper::deleteASClasses(ASClassVector& classes) {
   classes.clear();
 }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/Helper.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/Helper.hpp 
b/src/pdxautoserializer/impl/Helper.hpp
index e69bd77..4c46d93 100644
--- a/src/pdxautoserializer/impl/Helper.hpp
+++ b/src/pdxautoserializer/impl/Helper.hpp
@@ -32,7 +32,9 @@ extern "C" {
 }
 #endif
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * Class containing some static utility methods.
@@ -179,7 +181,9 @@ class Helper {
     return typeName;
   }
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_HELPER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/Log.cpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/Log.cpp 
b/src/pdxautoserializer/impl/Log.cpp
index 7c0c033..ade30cb 100644
--- a/src/pdxautoserializer/impl/Log.cpp
+++ b/src/pdxautoserializer/impl/Log.cpp
@@ -19,7 +19,9 @@
 #include <iostream>
 #include <stdexcept>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 static std::ostream* g_outStream = &std::cout;
 static std::ostream* g_errStream = &std::cerr;
@@ -47,4 +49,6 @@ void Log::debug(const std::string& moduleName, const 
std::string& message) {
 #endif
 }
 }  // namespace pdx_auto_serializer
-}  // namespace gemfire
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/Log.hpp
----------------------------------------------------------------------
diff --git a/src/pdxautoserializer/impl/Log.hpp 
b/src/pdxautoserializer/impl/Log.hpp
index e2dae06..0971fc6 100644
--- a/src/pdxautoserializer/impl/Log.hpp
+++ b/src/pdxautoserializer/impl/Log.hpp
@@ -21,7 +21,9 @@
 #include <string>
 #include <iosfwd>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /**
  * This class provides simple static functions to print messages on the
@@ -81,7 +83,9 @@ class Log {
   Log();
   Log(const Log&);
 };
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_LOG_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/Main.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/BasicOperations.cpp 
b/src/quickstart/cpp/BasicOperations.cpp
index ba27688..a8c7efc 100644
--- a/src/quickstart/cpp/BasicOperations.cpp
+++ b/src/quickstart/cpp/BasicOperations.cpp
@@ -35,7 +35,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The BasicOperations QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/CqQuery.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/CqQuery.cpp b/src/quickstart/cpp/CqQuery.cpp
index 57081c3..749b998 100644
--- a/src/quickstart/cpp/CqQuery.cpp
+++ b/src/quickstart/cpp/CqQuery.cpp
@@ -37,7 +37,7 @@
 #include "queryobjects/Position.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/DataExpiration.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/DataExpiration.cpp 
b/src/quickstart/cpp/DataExpiration.cpp
index a12ee1a..ec9d99d 100644
--- a/src/quickstart/cpp/DataExpiration.cpp
+++ b/src/quickstart/cpp/DataExpiration.cpp
@@ -41,7 +41,7 @@
 #include "plugins/SimpleCacheListener.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The DataExpiration QuickStart example.
 int main(int argc, char** argv) {
@@ -85,7 +85,7 @@ int main(int argc, char** argv) {
     LOGINFO("Got Entry Idle Timeout as %d seconds", entryIdleTimeout);
 
     // Wait for half the Entry Idle Timeout duration, using
-    // gemfire::millisleep().
+    // apache::geode::client::millisleep().
     millisleep(entryIdleTimeout * 1000 / 2);
 
     // Get the number of Keys remaining in the Region, should be all 3.
@@ -102,8 +102,8 @@ int main(int argc, char** argv) {
     LOGINFO("The SimpleCacheListener should next report the expiration 
action");
 
     // Wait for the entire Entry Idle Timeout duration, using
-    // gemfire::millisleep().
-    gemfire::millisleep(entryIdleTimeout * 1000);
+    // apache::geode::client::millisleep().
+    apache::geode::client::millisleep(entryIdleTimeout * 1000);
 
     // Get the number of Keys remaining in the Region, should be 0 now.
     regionPtr->keys(keys);

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/Delta.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/Delta.cpp b/src/quickstart/cpp/Delta.cpp
index 3b86f45..441997a 100644
--- a/src/quickstart/cpp/Delta.cpp
+++ b/src/quickstart/cpp/Delta.cpp
@@ -39,7 +39,7 @@
 #include "deltaobjects/DeltaExample.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The Delta QuickStart example.
 typedef SharedPtr<DeltaExample> DeltaExamplePtr;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/DistributedSystem.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/DistributedSystem.cpp 
b/src/quickstart/cpp/DistributedSystem.cpp
index e37d8b8..866ba95 100644
--- a/src/quickstart/cpp/DistributedSystem.cpp
+++ b/src/quickstart/cpp/DistributedSystem.cpp
@@ -39,7 +39,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 void distributedsystem(CachePtr cachePtr, char *hostname, int port,
                        char *poolName, char *regionName) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/DurableClient.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/DurableClient.cpp 
b/src/quickstart/cpp/DurableClient.cpp
index c1d45a3..d9e3c5a 100644
--- a/src/quickstart/cpp/DurableClient.cpp
+++ b/src/quickstart/cpp/DurableClient.cpp
@@ -36,7 +36,7 @@
 #include "plugins/DurableCacheListener.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 void RunDurableClient() {
   // Create durable client's properties using api.
@@ -83,7 +83,7 @@ void RunDurableClient() {
   LOGINFO("Sent ReadyForEvents message to server");
 
   // wait for some time to recieve events
-  gemfire::millisleep(1000);
+  apache::geode::client::millisleep(1000);
 
   // Close the GemFire Cache with keepalive = true.  Server will queue events
   // for

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/Exceptions.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/Exceptions.cpp 
b/src/quickstart/cpp/Exceptions.cpp
index aa5d995..fe3b614 100644
--- a/src/quickstart/cpp/Exceptions.cpp
+++ b/src/quickstart/cpp/Exceptions.cpp
@@ -34,7 +34,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The Exceptions QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/ExecuteFunctions.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/ExecuteFunctions.cpp 
b/src/quickstart/cpp/ExecuteFunctions.cpp
index 8aff830..47c5ecc 100644
--- a/src/quickstart/cpp/ExecuteFunctions.cpp
+++ b/src/quickstart/cpp/ExecuteFunctions.cpp
@@ -16,7 +16,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 char* getFuncIName = (char*)"MultiGetFunctionI";
 char* putFuncIName = (char*)"MultiPutFunctionI";

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/HACache.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/HACache.cpp b/src/quickstart/cpp/HACache.cpp
index ca139c6..4a7b9c4 100644
--- a/src/quickstart/cpp/HACache.cpp
+++ b/src/quickstart/cpp/HACache.cpp
@@ -34,7 +34,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The HA QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/LoaderListenerWriter.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/LoaderListenerWriter.cpp 
b/src/quickstart/cpp/LoaderListenerWriter.cpp
index 06e93b4..692837d 100644
--- a/src/quickstart/cpp/LoaderListenerWriter.cpp
+++ b/src/quickstart/cpp/LoaderListenerWriter.cpp
@@ -44,7 +44,7 @@
 #include "plugins/SimpleCacheWriter.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The LoaderListenerWriter QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/MultiuserSecurity.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/MultiuserSecurity.cpp 
b/src/quickstart/cpp/MultiuserSecurity.cpp
index 1048b91..888b89d 100644
--- a/src/quickstart/cpp/MultiuserSecurity.cpp
+++ b/src/quickstart/cpp/MultiuserSecurity.cpp
@@ -33,7 +33,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 char* getFuncIName = (char*)"MultiGetFunctionI";
 
@@ -174,7 +174,7 @@ int main(int argc, char** argv) {
           "writer2 was doing get operation.");
 
       return 1;
-    } catch (const gemfire::NotAuthorizedException& expected) {
+    } catch (const apache::geode::client::NotAuthorizedException& expected) {
       LOGINFO(
           "Got expected authorization failure while obtaining the Entry: %s",
           expected.getMessage());

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PdxAutoSerializer.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PdxAutoSerializer.cpp 
b/src/quickstart/cpp/PdxAutoSerializer.cpp
index 3170b6b..954108d 100644
--- a/src/quickstart/cpp/PdxAutoSerializer.cpp
+++ b/src/quickstart/cpp/PdxAutoSerializer.cpp
@@ -41,7 +41,7 @@
 #include "queryobjects/PositionPdxAuto.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PdxInstance.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PdxInstance.cpp 
b/src/quickstart/cpp/PdxInstance.cpp
index 02d3c49..5c5483e 100644
--- a/src/quickstart/cpp/PdxInstance.cpp
+++ b/src/quickstart/cpp/PdxInstance.cpp
@@ -34,7 +34,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class Person {
  private:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PdxRemoteQuery.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PdxRemoteQuery.cpp 
b/src/quickstart/cpp/PdxRemoteQuery.cpp
index b0c7930..12b61eb 100644
--- a/src/quickstart/cpp/PdxRemoteQuery.cpp
+++ b/src/quickstart/cpp/PdxRemoteQuery.cpp
@@ -41,7 +41,7 @@
 #include "queryobjects/PositionPdx.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PdxSerializer.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PdxSerializer.cpp 
b/src/quickstart/cpp/PdxSerializer.cpp
index e6f6b2a..a3664ec 100644
--- a/src/quickstart/cpp/PdxSerializer.cpp
+++ b/src/quickstart/cpp/PdxSerializer.cpp
@@ -37,7 +37,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 static const char* CLASSNAME = "com.example.Person";
 

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PoolCqQuery.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PoolCqQuery.cpp 
b/src/quickstart/cpp/PoolCqQuery.cpp
index 2598c34..e8b1d8e 100644
--- a/src/quickstart/cpp/PoolCqQuery.cpp
+++ b/src/quickstart/cpp/PoolCqQuery.cpp
@@ -40,7 +40,7 @@
 #include "queryobjects/Position.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PoolRemoteQuery.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PoolRemoteQuery.cpp 
b/src/quickstart/cpp/PoolRemoteQuery.cpp
index c5eb688..c00df4b 100644
--- a/src/quickstart/cpp/PoolRemoteQuery.cpp
+++ b/src/quickstart/cpp/PoolRemoteQuery.cpp
@@ -41,7 +41,7 @@
 #include "queryobjects/Position.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PoolWithEndpoints.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PoolWithEndpoints.cpp 
b/src/quickstart/cpp/PoolWithEndpoints.cpp
index c8b8d3a..44f7586 100644
--- a/src/quickstart/cpp/PoolWithEndpoints.cpp
+++ b/src/quickstart/cpp/PoolWithEndpoints.cpp
@@ -37,7 +37,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The PoolWithEndpoints QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/PutAllGetAllOperations.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/PutAllGetAllOperations.cpp 
b/src/quickstart/cpp/PutAllGetAllOperations.cpp
index d7f6603..ad50072 100644
--- a/src/quickstart/cpp/PutAllGetAllOperations.cpp
+++ b/src/quickstart/cpp/PutAllGetAllOperations.cpp
@@ -33,7 +33,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The PutAllGetAllOperations QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/RefIDExample.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/RefIDExample.cpp 
b/src/quickstart/cpp/RefIDExample.cpp
index f086330..5c06cb0 100644
--- a/src/quickstart/cpp/RefIDExample.cpp
+++ b/src/quickstart/cpp/RefIDExample.cpp
@@ -38,7 +38,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The RefIDExample QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/RegisterInterest.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/RegisterInterest.cpp 
b/src/quickstart/cpp/RegisterInterest.cpp
index 50f5ba4..ac88bb1 100644
--- a/src/quickstart/cpp/RegisterInterest.cpp
+++ b/src/quickstart/cpp/RegisterInterest.cpp
@@ -35,7 +35,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The RegisterInterest QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/RemoteQuery.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/RemoteQuery.cpp 
b/src/quickstart/cpp/RemoteQuery.cpp
index 4de7381..192778b 100644
--- a/src/quickstart/cpp/RemoteQuery.cpp
+++ b/src/quickstart/cpp/RemoteQuery.cpp
@@ -38,7 +38,7 @@
 #include "queryobjects/Position.hpp"
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // Use the "testobject" namespace for the query objects.
 using namespace testobject;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/Security.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/Security.cpp b/src/quickstart/cpp/Security.cpp
index c1be24f..a46311f 100644
--- a/src/quickstart/cpp/Security.cpp
+++ b/src/quickstart/cpp/Security.cpp
@@ -31,7 +31,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The Security QuickStart example.
 int main(int argc, char** argv) {
@@ -74,7 +74,7 @@ int main(int argc, char** argv) {
       CacheablePtr result1Ptr = regionPtr->get("Key1");
 
       // collect NotAuthorized exception
-    } catch (const gemfire::NotAuthorizedException& expected) {
+    } catch (const apache::geode::client::NotAuthorizedException& expected) {
       LOGINFO(
           "Got expected authorization failure while obtaining the Entry: %s",
           expected.getMessage());

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/Transactions.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/Transactions.cpp 
b/src/quickstart/cpp/Transactions.cpp
index 5a1bde6..1561e3c 100644
--- a/src/quickstart/cpp/Transactions.cpp
+++ b/src/quickstart/cpp/Transactions.cpp
@@ -39,7 +39,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The Transaction QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/TransactionsXA.cpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/TransactionsXA.cpp 
b/src/quickstart/cpp/TransactionsXA.cpp
index 5a43f7e..1b198d9 100644
--- a/src/quickstart/cpp/TransactionsXA.cpp
+++ b/src/quickstart/cpp/TransactionsXA.cpp
@@ -41,7 +41,7 @@
 #include <gfcpp/GemfireCppCache.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The Transaction QuickStart example.
 int main(int argc, char** argv) {

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/deltaobjects/DeltaExample.hpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/deltaobjects/DeltaExample.hpp 
b/src/quickstart/cpp/deltaobjects/DeltaExample.hpp
index aba98c0..65ebfbf 100644
--- a/src/quickstart/cpp/deltaobjects/DeltaExample.hpp
+++ b/src/quickstart/cpp/deltaobjects/DeltaExample.hpp
@@ -20,7 +20,7 @@
 
 #include <gfcpp/GemfireCppCache.hpp>
 
-using namespace gemfire;
+using namespace apache::geode::client;
 
 class DeltaExample : public Cacheable, public Delta {
  private:

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/plugins/DurableCacheListener.hpp
----------------------------------------------------------------------
diff --git a/src/quickstart/cpp/plugins/DurableCacheListener.hpp 
b/src/quickstart/cpp/plugins/DurableCacheListener.hpp
index 7bf05a5..b7c02e2 100644
--- a/src/quickstart/cpp/plugins/DurableCacheListener.hpp
+++ b/src/quickstart/cpp/plugins/DurableCacheListener.hpp
@@ -28,7 +28,7 @@
 #include <gfcpp/CacheListener.hpp>
 
 // Use the "gemfire" namespace.
-using namespace gemfire;
+using namespace apache::geode::client;
 
 // The SimpleCacheListener class.
 class DurableCacheListener : public CacheListener {

Reply via email to
diff --git a/src/pdxautoserializer/base_types.hpp 
b/src/pdxautoserializer/base_types.hpp
index 4e052fb..570b82f 100644
--- a/src/pdxautoserializer/base_types.hpp
+++ b/src/pdxautoserializer/base_types.hpp
@@ -25,7 +25,9 @@
 #include <cassert>
 #include <stdexcept>
 
-namespace gemfire {
+namespace apache {
+namespace geode {
+namespace client {
 namespace pdx_auto_serializer {
 /** Shorthand for vector of strings. */
 typedef std::vector<std::string> StringVector;
@@ -180,10 +182,12 @@ class TypeModifier {
  * Structure to hold information for a type.
  */
 struct TypeInfo {
   /** The {@link gemfire::pdx_auto_serializer::TypeKind} of the type. */
   int m_kind;
 
   /** The {@link gemfire::pdx_auto_serializer::TypeModifier} for the type. */
   int m_modifier;
 
   /**
@@ -242,7 +246,9 @@ typedef std::vector<VariableInfo> VariableVector;
  * <code>VariableInfo</code>.
  */
 typedef std::vector<VariableInfo>::const_iterator VariableVectorIterator;
-}
-}
+}  // namespace pdx_auto_serializer
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GFAS_BASETYPES_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/pdxautoserializer/impl/CPPCodeGenerator.cpp
----------------------------------------------------------------------
@@ -180,10 +182,12 @@ class TypeModifier {
  */
 struct TypeInfo {
-  /** The {@link gemfire::pdx_auto_serializer::TypeKind} of the type. */
+  /** The {@link apache::geode::client::pdx_auto_serializer::TypeKind} of the
+   * type. */
   int m_kind;
 
@@ -180,10 +182,12 @@ class TypeModifier {
   int m_kind;
 
-  /** The {@link gemfire::pdx_auto_serializer::TypeModifier} for the type. */
+  /** The {@link apache::geode::client::pdx_auto_serializer::TypeModifier} for
+   * the type. */
   int m_modifier;
 
diff --git a/src/pdxautoserializer/impl/Main.cpp 
b/src/pdxautoserializer/impl/Main.cpp
index 6de78f8..42e651f 100644
--- a/src/pdxautoserializer/impl/Main.cpp
+++ b/src/pdxautoserializer/impl/Main.cpp
@@ -24,10 +24,11 @@
 #include <iostream>
 
 /**
 * @namespace gemfire::pdx_auto_serializer The namespace containing the
containing
+* the
 *                                     auto-serializer classes.
 */
-using namespace gemfire::pdx_auto_serializer;
+using namespace apache::geode::client::pdx_auto_serializer;
 
 /** The name used for invocation of the program on command-line. */
 std::string progName;

http://git-wip-us.apache.org/repos/asf/geode/blob/e4fd74fb/src/quickstart/cpp/BasicOperations.cpp
----------------------------------------------------------------------
@@ -24,10 +24,11 @@
 
 /**
-* @namespace gemfire::pdx_auto_serializer The namespace containing the
+* @namespace apache::geode::client::pdx_auto_serializer The namespace 
containing